pub struct Session {
pub id: u64,
pub pty: Pty,
pub title: Option<String>,
pub exited: bool,
pub exit_code: Option<i32>,
pub cols: u16,
pub rows: u16,
}Fields
id: u64pty: Ptytitle: Option<String>exited: boolexit_code: Option<i32>cols: u16rows: u16Implementations
Sourceimpl Session
impl Session
pub fn spawn( id: u64, cmd: Option<Vec<String>>, cols: u16, rows: u16, channel: Option<&ChannelName>, ) -> PtyResult<Self>
pub fn read_output(&mut self) -> Vec<u8> ⓘ
Sourcepub fn sync_screen(&mut self)
pub fn sync_screen(&mut self)
Sync screen state without draining pending output. Clears the dirty flag (waking the reader thread from I/O burst budget parking) and syncs the title, but leaves accumulated bytes in the pending buffer so they can be sent to a future subscriber.
pub fn check_exited(&mut self) -> bool
pub fn take_exit_code(&mut self) -> Option<i32>
pub fn generate_snapshot(&mut self) -> Vec<u8> ⓘ
pub fn set_status_callback( &mut self, cb: Option<Box<dyn Fn(PtyStatus) + Send + Sync>>, )